# skyway
Skyway is a small, lightweight python library that can be used to access OpenStreetMap data via the Overpass service. It is intended to be used in the automation of satellite imagery data labeling, but is also a standalone API for any kind of Overpass access. This project is under heavy development.


This library currently depends on a branch of the `tiletanic` library that is not on PyPi. 

To install run the following:

```console
$ pip install git+https://github.com/DigitalGlobe/tiletanic.git@geotile
$ python setup.py install
``` 


## Examples

To run the examples, you will need to have Jupyter Notebooks installed:

```console
$ pip install -r requirements_dev.txt
```